@@ -1,5 +1,5 @@
 from lucas_helpers_webforce import database
-from lucas_helpers_webforce.events import *
+from lucas_helpers_webforce import bus_events
 from lucas_helpers_webforce import libraries
 from lucas_helpers_webforce import models
 from lucas_helpers_webforce import queues
\ No newline at end of file
